Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(272)

Unified Diff: components/test_runner/test_runner.h

Issue 1847893002: Extract WebFrameClient implementation out of WebTestProxyBase. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Revert some changes to mock_color_chooser.cc + fix counting of TestRunner::chooser_count_. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/test_runner/test_common.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/test_runner/test_runner.h
diff --git a/components/test_runner/test_runner.h b/components/test_runner/test_runner.h
index 5a769a831aee3ef052120e30ace2e2da2de61f88..a0728a545769a001ec355f0ed67c985d13aa3651 100644
--- a/components/test_runner/test_runner.h
+++ b/components/test_runner/test_runner.h
@@ -42,6 +42,7 @@ namespace test_runner {
class InvokeCallbackTask;
class MockScreenOrientationClient;
+class MockWebUserMediaClient;
class TestInterfaces;
class WebContentSettings;
class WebTestDelegate;
@@ -81,9 +82,10 @@ class TestRunner : public WebTestRunner,
bool ShouldDumpBackForwardList() const override;
blink::WebContentSettingsClient* GetWebContentSettings() const override;
// Methods used by WebTestProxyBase.
bool shouldStayOnPageAfterHandlingBeforeUnload() const;
MockScreenOrientationClient* getMockScreenOrientationClient();
+ MockWebUserMediaClient* getMockWebUserMediaClient();
bool shouldDumpSelectionRect() const;
bool isPrinting() const;
bool shouldDumpAsTextWithPixelResults();
@@ -131,6 +133,10 @@ class TestRunner : public WebTestRunner,
bool midiAccessorResult();
+ // Methods used by MockColorChooser:
+ void DidOpenChooser();
+ void DidCloseChooser();
+
// A single item in the work queue.
class WorkItem {
public:
@@ -805,6 +811,10 @@ class TestRunner : public WebTestRunner,
bool use_mock_theme_;
scoped_ptr<MockScreenOrientationClient> mock_screen_orientation_client_;
+ scoped_ptr<MockWebUserMediaClient> user_media_client_;
+
+ // Number of currently active color choosers.
+ int chooser_count_;
base::WeakPtrFactory<TestRunner> weak_factory_;
« no previous file with comments | « components/test_runner/test_common.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »
@@ -81,9 +82,10 @@ class TestRunner : public WebTestRunner,
bool ShouldDumpBackForwardList() const override;
blink::WebContentSettingsClient* GetWebContentSettings() const override;
- // Methods used by WebTestProxyBase.
+ // Methods used by WebTestProxyBase and WebFrameTestClient.
bool shouldStayOnPageAfterHandlingBeforeUnload() const;
MockScreenOrientationClient* getMockScreenOrientationClient();

Powered by Google App Engine
This is Rietveld 408576698